.. _documentation_index:
.. BIOM documentation

.. index:: Documentation

==================
BIOM Documentation
==================
These pages provide format specifications and API information for the BIOM table objects.

.. toctree::
   :maxdepth: 2
      
   biom_format
   quick_usage_examples
   table_objects
   biom_conversion
   adding_metadata
   summarizing_biom_tables
